# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector_v2.models.expanded_notification_response import ExpandedNotificationResponse

class TestExpandedNotificationResponse(unittest.TestCase):
    """ExpandedNotificationResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ExpandedNotificationResponse:
        """Test ExpandedNotificationResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ExpandedNotificationResponse`
        """
        model = ExpandedNotificationResponse()
        if include_optional:
            return ExpandedNotificationResponse(
                id = 56,
                source_type = '',
                source_id = 56,
                portal_id = 56,
                portal_member = notifications_server_connector_v2.models.notification_author_response.NotificationAuthorResponse(
                    id = 56, 
                    email = '', 
                    role_id = 56, 
                    first_name = '', 
                    last_name = '', 
                    nickname = '', 
                    avatar_id = '', ),
                title = '',
                message = '',
                is_anonymous = True,
                parent_id = 56,
                parent_name = '',
                created_at = 56,
                visit_url = '',
                visit_url_mobile = '',
                fcm_topic = '',
                portal_member_name = '',
                seen = True
            )
        else:
            return ExpandedNotificationResponse(
                id = 56,
                source_type = '',
                source_id = 56,
                portal_id = 56,
                title = '',
                message = '',
                created_at = 56,
        )
        """

    def testExpandedNotificationResponse(self):
        """Test ExpandedNotificationResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
