# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictBool, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from notifications_server_connector_v2.models.source_type_id import SourceTypeId
from typing import Optional, Set
from typing_extensions import Self

class SendNotificationRequest(BaseModel):
    """
    SendNotificationRequest
    """ # noqa: E501
    source_type_id: SourceTypeId
    source_id: StrictInt
    portal_id: StrictInt
    portal_member_id: StrictInt
    title: StrictStr
    message: StrictStr
    is_anonymous: Optional[StrictBool] = False
    parent_id: Optional[StrictInt] = None
    parent_name: Optional[StrictStr] = None
    created_at: Optional[StrictInt] = None
    fcm_topic: Optional[StrictStr] = None
    notification_receivers: Optional[List[StrictInt]] = None
    args: Optional[Dict[str, Any]] = None
    extra_email_receivers: Optional[List[StrictStr]] = Field(default=None, description="Email addresses for non-portal members")
    __properties: ClassVar[List[str]] = ["source_type_id", "source_id", "portal_id", "portal_member_id", "title", "message", "is_anonymous", "parent_id", "parent_name", "created_at", "fcm_topic", "notification_receivers", "args", "extra_email_receivers"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SendNotificationRequest from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of source_type_id
        if self.source_type_id:
            _dict['source_type_id'] = self.source_type_id.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SendNotificationRequest from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "source_type_id": SourceTypeId.from_dict(obj["source_type_id"]) if obj.get("source_type_id") is not None else None,
            "source_id": obj.get("source_id"),
            "portal_id": obj.get("portal_id"),
            "portal_member_id": obj.get("portal_member_id"),
            "title": obj.get("title"),
            "message": obj.get("message"),
            "is_anonymous": obj.get("is_anonymous") if obj.get("is_anonymous") is not None else False,
            "parent_id": obj.get("parent_id"),
            "parent_name": obj.get("parent_name"),
            "created_at": obj.get("created_at"),
            "fcm_topic": obj.get("fcm_topic"),
            "notification_receivers": obj.get("notification_receivers"),
            "args": obj.get("args"),
            "extra_email_receivers": obj.get("extra_email_receivers")
        })
        return _obj


