# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector_v2.models.wrapped_response_user_notification_settings_response import WrappedResponseUserNotificationSettingsResponse

class TestWrappedResponseUserNotificationSettingsResponse(unittest.TestCase):
    """WrappedResponseUserNotificationSettingsResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> WrappedResponseUserNotificationSettingsResponse:
        """Test WrappedResponseUserNotificationSettingsResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `WrappedResponseUserNotificationSettingsResponse`
        """
        model = WrappedResponseUserNotificationSettingsResponse()
        if include_optional:
            return WrappedResponseUserNotificationSettingsResponse(
                done = True,
                result = notifications_server_connector_v2.models.user_notification_settings_response.UserNotificationSettingsResponse(
                    id = 56, 
                    user_id = 56, 
                    receive_email_notifications = True, 
                    receive_in_app_notifications = True, )
            )
        else:
            return WrappedResponseUserNotificationSettingsResponse(
                result = notifications_server_connector_v2.models.user_notification_settings_response.UserNotificationSettingsResponse(
                    id = 56, 
                    user_id = 56, 
                    receive_email_notifications = True, 
                    receive_in_app_notifications = True, ),
        )
        """

    def testWrappedResponseUserNotificationSettingsResponse(self):
        """Test WrappedResponseUserNotificationSettingsResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
