# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector_v2.api.user_settings_api import UserSettingsApi


class TestUserSettingsApi(unittest.IsolatedAsyncioTestCase):
    """UserSettingsApi unit test stubs"""

    async def asyncSetUp(self) -> None:
        self.api = UserSettingsApi()

    async def asyncTearDown(self) -> None:
        await self.api.api_client.close()

    async def test_user_settings_get_user_notification_settings(self) -> None:
        """Test case for user_settings_get_user_notification_settings

        Get user notification settings
        """
        pass

    async def test_user_settings_set_user_notification_settings(self) -> None:
        """Test case for user_settings_set_user_notification_settings

        Set user notification settings
        """
        pass

    async def test_user_settings_unsubscribe_by_token(self) -> None:
        """Test case for user_settings_unsubscribe_by_token

        Unsubscribe by token
        """
        pass


if __name__ == '__main__':
    unittest.main()
