# coding: utf-8

"""
    Mentortools Notifications Server

    Mentortools service for Notifications

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from notifications_server_connector_v2.models.portal_template_override_response import PortalTemplateOverrideResponse

class TestPortalTemplateOverrideResponse(unittest.TestCase):
    """PortalTemplateOverrideResponse unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PortalTemplateOverrideResponse:
        """Test PortalTemplateOverrideResponse
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PortalTemplateOverrideResponse`
        """
        model = PortalTemplateOverrideResponse()
        if include_optional:
            return PortalTemplateOverrideResponse(
                source_type_id = 56,
                source_type = notifications_server_connector_v2.models.overridable_source_type_response.OverridableSourceTypeResponse(
                    id = 56, 
                    name = '', 
                    allowed_variables = [
                        ''
                        ], ),
                subject = '',
                body = '',
                is_override = True,
                created_at = 56,
                updated_at = 56
            )
        else:
            return PortalTemplateOverrideResponse(
                source_type_id = 56,
                source_type = notifications_server_connector_v2.models.overridable_source_type_response.OverridableSourceTypeResponse(
                    id = 56, 
                    name = '', 
                    allowed_variables = [
                        ''
                        ], ),
                subject = '',
                body = '',
                is_override = True,
        )
        """

    def testPortalTemplateOverrideResponse(self):
        """Test PortalTemplateOverrideResponse"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
